Index: chrome/test/automation/automation_messages_internal.h |
diff --git a/chrome/common/automation_messages_internal.h b/chrome/test/automation/automation_messages_internal.h |
similarity index 99% |
rename from chrome/common/automation_messages_internal.h |
rename to chrome/test/automation/automation_messages_internal.h |
index ab3c97c4908b921c4a4a0c2cc72aaf012662f3ef..adadf68183f1dffcef91ce12ae44b5f04e1fd378 100644 |
--- a/chrome/common/automation_messages_internal.h |
+++ b/chrome/test/automation/automation_messages_internal.h |
@@ -611,8 +611,9 @@ IPC_BEGIN_MESSAGES(Automation) |
// - int: handle of the tab |
// Response: |
// - bool: whether the operation was successful. |
- // - PageType: the type of the page currently displayed. |
- IPC_SYNC_MESSAGE_ROUTED1_2(AutomationMsg_GetPageType, int, bool, PageType) |
+ // - NavigationEntry::PageType: the type of the page currently displayed. |
+ IPC_SYNC_MESSAGE_ROUTED1_2(AutomationMsg_GetPageType, int, bool, |
+ NavigationEntry::PageType) |
// This message simulates the user action on the SSL blocking page showing in |
// the specified tab. This message is only effective if an interstitial page |
@@ -951,7 +952,7 @@ IPC_BEGIN_MESSAGES(Automation) |
int /* tab_handle */, |
HANDLE /* source menu handle */, |
int /* align flags */, |
- IPC::MiniContextMenuParams /* params */) |
+ IPC::ContextMenuParams /* params */) |
IPC_MESSAGE_ROUTED2(AutomationMsg_ForwardContextMenuCommandToChrome, |
int /* tab_handle */, |